@@ -1,12 +1,8 @@
-import random
 import os
 import pele_platform.constants.constants as cs
-from pele_platform.Utilities.Parameters.SimulationFolders.MSMFolders import msm_folders
-from pele_platform.Utilities.Parameters.SimulationFolders.GlideFolders import glide_folders
-import pele_platform.Utilities.Helpers.helpers as hp
 
 
-class SimulationPaths(msm_folders.MSMPaths, glide_folders.GlidePaths):
+class SimulationPaths():
 
 
     def __init__(self, args):
@@ -18,10 +14,12 @@ class SimulationPaths(msm_folders.MSMPaths, glide_folders.GlidePaths):
 
 
     def working_folder_paths(self, args):
-
-        self.system_fix = os.path.join(self.pele_dir, "{}_processed.pdb".format(os.path.splitext(os.path.basename(self.system))[0]))
-
+        if self.no_ppp:
+            self.system_fix = os.path.join(self.pele_dir, os.path.basename(self.system))
+        else:
+            self.system_fix = os.path.join(self.pele_dir, "{}_processed.pdb".format(os.path.splitext(os.path.basename(self.system))[0]))
         self.adap_ex_input = os.path.basename(self.system_fix)
+
         self.pele_temp = os.path.join(self.pele_dir, "pele.conf")
         self.adap_l_input = "{}/initial_*"
         self.adap_l_output = os.path.join(self.pele_dir, "output_pele")
